@@ -11,11 +11,11 @@ def facebook_download(url, output_dir='.', merge=True, info_only=False, **kwargs
     title = r1(r'<title id="pageTitle">(.+)</title>', html)
     sd_urls = list(set([
         unicodize(str.replace(i, '\\/', '/'))
-        for i in re.findall(r'"sd_src_no_ratelimit":"([^"]*)"', html)
+        for i in re.findall(r'sd_src_no_ratelimit:"([^"]*)"', html)
     ]))
     hd_urls = list(set([
         unicodize(str.replace(i, '\\/', '/'))
-        for i in re.findall(r'"hd_src_no_ratelimit":"([^"]*)"', html)
+        for i in re.findall(r'hd_src_no_ratelimit:"([^"]*)"', html)
     ]))
     urls = hd_urls if hd_urls else sd_urls
 
